export function base64toBlob(b64Data, contentType, sliceSize) {
    contentType = contentType || '';
    sliceSize = sliceSize || 512;
    var byteCharacters = atob(b64Data);
    var byteArrays = [];
    for (var offset = 0; offset < byteCharacters.length; offset += sliceSize) {
        var slice = byteCharacters.slice(offset, offset + sliceSize);
        var byteNumbers = new Array(slice.length);
        for (var i = 0; i < slice.length; i++) {
            byteNumbers[i] = slice.charCodeAt(i);
        }
        var byteArray = new Uint8Array(byteNumbers);
        byteArrays.push(byteArray);
    }
    var blob = new Blob(byteArrays, { type: contentType });
    return blob;
}
export function rotateBase64Image(imageData, degrees) {
    return new Promise(function (resolve) {
        var canvas = document.createElement('canvas');
        var canvasContext = canvas.getContext('2d');
        var image = new Image();
        image.onload = function () {
            if ((degrees / 90) % 2 === 0) {
                canvas.width = image.width;
                canvas.height = image.height;
            }
            else {
                canvas.width = image.height;
                canvas.height = image.width;
            }
            switch (degrees) {
                case 90:
                    canvasContext.translate(canvas.width, 0);
                    break;
                case 180:
                    canvasContext.translate(canvas.width, canvas.height);
                    break;
                case 270:
                    canvasContext.translate(0, canvas.height);
                    break;
            }
            canvasContext.rotate(degrees * Math.PI / 180);
            canvasContext.drawImage(image, 0, 0);
            var dataUrl = canvas.toDataURL('image/jpeg');
            resolve(dataUrl.replace('data:image/jpeg;base64,', ''));
        };
        image.src = 'data:image/jpeg;base64,' + imageData;
    });
}
//# sourceMappingURL=picture-mutations.js.map